/* machine.c generated by valac 0.17.2.20-113d, the Vala compiler
 * generated from machine.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <cairo.h>
#include <clutter-gtk/clutter-gtk.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PAIR (boxes_pair_get_type ())
#define BOXES_PAIR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PAIR, BoxesPair))
#define BOXES_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PAIR, BoxesPairClass))
#define BOXES_IS_PAIR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PAIR))
#define BOXES_IS_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PAIR))
#define BOXES_PAIR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PAIR, BoxesPairClass))

typedef struct _BoxesPair BoxesPair;
typedef struct _BoxesPairClass BoxesPairClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_TYPE_MACHINE_ACTOR (boxes_machine_actor_get_type ())
#define BOXES_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActor))
#define BOXES_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))
#define BOXES_IS_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_IS_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_MACHINE_ACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))

typedef struct _BoxesMachineActor BoxesMachineActor;
typedef struct _BoxesMachineActorClass BoxesMachineActorClass;

#define BOXES_TYPE_COLLECTION_SOURCE (boxes_collection_source_get_type ())
#define BOXES_COLLECTION_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSource))
#define BOXES_COLLECTION_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSourceClass))
#define BOXES_IS_COLLECTION_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_SOURCE))
#define BOXES_IS_COLLECTION_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_SOURCE))
#define BOXES_COLLECTION_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSourceClass))

typedef struct _BoxesCollectionSource BoxesCollectionSource;
typedef struct _BoxesCollectionSourceClass BoxesCollectionSourceClass;

#define BOXES_TYPE_DISPLAY_CONFIG (boxes_display_config_get_type ())
#define BOXES_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfig))
#define BOXES_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))
#define BOXES_IS_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_IS_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_DISPLAY_CONFIG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))

typedef struct _BoxesDisplayConfig BoxesDisplayConfig;
typedef struct _BoxesDisplayConfigClass BoxesDisplayConfigClass;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;
typedef struct _BoxesMachineTakeScreenshotData BoxesMachineTakeScreenshotData;
typedef struct _BoxesMachineUpdateScreenshotData BoxesMachineUpdateScreenshotData;
#define _cairo_pattern_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_pattern_destroy (var), NULL)))
#define _cairo_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_destroy (var), NULL)))
#define _cairo_surface_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_surface_destroy (var), NULL)))
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))
typedef struct _BoxesMachineActorPrivate BoxesMachineActorPrivate;
typedef struct _BoxesPropertiesPrivate BoxesPropertiesPrivate;
typedef struct _Block16Data Block16Data;
typedef struct _Block17Data Block17Data;
typedef struct _Block18Data Block18Data;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesMachineActor* machine_actor;
	BoxesCollectionSource* source;
	BoxesDisplayConfig* config;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	gchar* (*get_screenshot_prefix) (BoxesMachine* self);
	void (*connect_display) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED
} BoxesMachineMachineState;

struct _BoxesMachinePrivate {
	GdkPixbuf* _pixbuf;
	gulong show_id;
	gulong hide_id;
	gulong disconnected_id;
	gulong need_password_id;
	gulong need_username_id;
	gulong ui_state_id;
	guint screenshot_id;
	gboolean updating_screenshot;
	BoxesMachineMachineState _state;
	BoxesDisplay* _display;
	gint screenshot_counter;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	GtkClutterEmbed* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* topbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesCollection* collection;
	GSimpleAction* action_properties;
	GSimpleAction* action_fullscreen;
	GSimpleAction* action_shutdown;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _BoxesMachineTakeScreenshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
	GdkPixbuf* result;
};

typedef enum  {
	BOXES_ERROR_INVALID,
	BOXES_ERROR_COMMAND_FAILED
} BoxesError;
#define BOXES_ERROR boxes_error_quark ()
struct _BoxesMachineUpdateScreenshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMachine* self;
	gboolean force_save;
	gboolean first_check;
	gboolean _tmp0_;
	GdkPixbuf* large_screenshot;
	GdkPixbuf* _tmp1_;
	GdkPixbuf* _tmp2_;
	gboolean _tmp3_;
	GdkPixbuf* _tmp4_;
	GdkPixbuf* _tmp5_;
	GError* _error_;
	gboolean _tmp6_;
	gboolean _tmp7_;
	gint _tmp8_;
	GdkPixbuf* _tmp9_;
	gboolean _tmp10_;
	GError * _inner_error_;
};

struct _BoxesMachineActor {
	BoxesUI parent_instance;
	BoxesMachineActorPrivate * priv;
	ClutterActor* _actor;
};

struct _BoxesMachineActorClass {
	BoxesUIClass parent_class;
};

struct _BoxesMachineActorPrivate {
	GtkClutterTexture* screenshot;
	GtkClutterActor* gtk_vbox;
	GtkClutterActor* display;
	GtkLabel* label;
	GtkVBox* vbox;
	GtkEntry* password_entry;
	BoxesMachine* machine;
	gulong track_screenshot_id;
};

struct _BoxesProperties {
	BoxesUI parent_instance;
	BoxesPropertiesPrivate * priv;
	GtkWidget* screenshot_placeholder;
};

struct _BoxesPropertiesClass {
	BoxesUIClass parent_class;
};

struct _Block16Data {
	int _ref_count_;
	BoxesMachineActor * self;
	BoxesMachine* machine;
};

struct _Block17Data {
	int _ref_count_;
	BoxesMachineActor * self;
	gboolean completed_zoom;
	gulong completed_id;
};

struct _Block18Data {
	int _ref_count_;
	Block17Data * _data17_;
	GtkAllocation alloc;
};


static gpointer boxes_machine_parent_class = NULL;
static cairo_surface_t* boxes_machine_grid_surface;
static cairo_surface_t* boxes_machine_grid_surface = NULL;
static GdkPixbuf* boxes_machine_default_fallback;
static GdkPixbuf* boxes_machine_default_fallback = NULL;
extern BoxesApp* boxes_app_app;
static BoxesIPropertiesProviderIface* boxes_machine_boxes_iproperties_provider_parent_iface = NULL;
static gpointer boxes_machine_actor_parent_class = NULL;

GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
gpointer boxes_pair_ref (gpointer instance);
void boxes_pair_unref (gpointer instance);
GParamSpec* boxes_param_spec_pair (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_pair (GValue* value, gpointer v_object);
void boxes_value_take_pair (GValue* value, gpointer v_object);
gpointer boxes_value_get_pair (const GValue* value);
GType boxes_pair_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_machine_actor_get_type (void) G_GNUC_CONST;
GType boxes_collection_source_get_type (void) G_GNUC_CONST;
GType boxes_display_config_get_type (void) G_GNUC_CONST;
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
#define BOXES_MACHINE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_MACHINE, BoxesMachinePrivate))
enum  {
	BOXES_MACHINE_DUMMY_PROPERTY,
	BOXES_MACHINE_ACTOR,
	BOXES_MACHINE_PIXBUF,
	BOXES_MACHINE_STATE,
	BOXES_MACHINE_DISPLAY
};
#define BOXES_MACHINE_SCREENSHOT_WIDTH 180
#define BOXES_MACHINE_SCREENSHOT_HEIGHT 134
BoxesMachine* boxes_machine_construct (GType object_type, BoxesCollectionSource* source, const gchar* name);
BoxesCollectionItem* boxes_collection_item_construct (GType object_type);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
static GdkPixbuf* boxes_machine_draw_fallback_vm (gint width, gint height, gboolean force);
void boxes_machine_set_pixbuf (BoxesMachine* self, GdkPixbuf* value);
BoxesMachineActor* boxes_machine_actor_new (BoxesMachine* machine);
BoxesMachineActor* boxes_machine_actor_construct (GType object_type, BoxesMachine* machine);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void __lambda87_ (BoxesMachine* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_machine_set_screenshot_enable (BoxesMachine* self, gboolean enable);
static void ___lambda87__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_machine_load_screenshot (BoxesMachine* self);
gchar* boxes_machine_get_screenshot_filename (BoxesMachine* self);
void boxes_machine_set_screenshot (BoxesMachine* self, GdkPixbuf* large_screenshot, gboolean save);
void boxes_machine_update_screenshot (BoxesMachine* self, gboolean force_save, gboolean first_check, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_update_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_);
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
static gboolean ___lambda50_ (BoxesMachine* self);
static gboolean ____lambda50__gsource_func (gpointer self);
gchar* boxes_get_user_pkgcache (const gchar* file_name);
gchar* boxes_machine_get_screenshot_prefix (BoxesMachine* self);
static void boxes_machine_real_take_screenshot_data_free (gpointer _data);
static void boxes_machine_real_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GdkPixbuf* boxes_machine_take_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_machine_real_take_screenshot_co (BoxesMachineTakeScreenshotData* _data_);
GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page);
static GList* boxes_machine_real_get_properties (BoxesMachine* self, BoxesPropertiesPage page);
static gchar* boxes_machine_real_get_screenshot_prefix (BoxesMachine* self);
void boxes_machine_connect_display (BoxesMachine* self);
static void boxes_machine_real_connect_display (BoxesMachine* self);
void boxes_machine_disconnect_display (BoxesMachine* self);
static void boxes_machine_real_disconnect_display (BoxesMachine* self);
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
GQuark boxes_error_quark (void);
GdkPixbuf* boxes_display_get_pixbuf (BoxesDisplay* self, gint n, GError** error);
GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self);
void boxes_display_disconnect_it (BoxesDisplay* self);
void boxes_machine_set_display (BoxesMachine* self, BoxesDisplay* value);
gboolean boxes_machine_is_running (BoxesMachine* self);
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static GdkPixbuf* boxes_machine_draw_vm (BoxesMachine* self, GdkPixbuf* pixbuf, gint width, gint height);
void boxes_machine_actor_set_screenshot (BoxesMachineActor* self, GdkPixbuf* pixbuf);
GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self);
static void boxes_machine_update_screenshot_data_free (gpointer _data);
static gboolean boxes_machine_update_screenshot_co (BoxesMachineUpdateScreenshotData* _data_);
static void boxes_machine_update_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_machine_delete (BoxesMachine* self, gboolean by_user);
static void boxes_machine_real_delete (BoxesMachine* self, gboolean by_user);
static void boxes_machine_real_ui_state_changed (BoxesUI* base);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
void boxes_machine_set_state (BoxesMachine* self, BoxesMachineMachineState value);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
const gchar* boxes_machine_machine_state_to_string (BoxesMachineMachineState self);
static void _boxes_machine_display___lambda20_ (BoxesMachine* self, gint id);
static gboolean __lambda21_ (BoxesMachine* self);
GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n, GError** error);
void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget);
static gboolean ___lambda21__gsource_func (gpointer self);
static void __boxes_machine_display___lambda20__boxes_display_show (BoxesDisplay* _sender, gint display_id, gpointer self);
static void _boxes_machine_display___lambda33_ (BoxesMachine* self, gint id);
static void __boxes_machine_display___lambda33__boxes_display_hide (BoxesDisplay* _sender, gint display_id, gpointer self);
static void _boxes_machine_display___lambda34_ (BoxesMachine* self);
static void __boxes_machine_display___lambda34__boxes_display_disconnected (BoxesDisplay* _sender, gpointer self);
static void _boxes_machine_display___lambda35_ (BoxesMachine* self);
void boxes_machine_actor_set_password_needed (BoxesMachineActor* self, gboolean needed);
gboolean boxes_display_get_need_password (BoxesDisplay* self);
static void __boxes_machine_display___lambda35__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_machine_display___lambda36_ (BoxesMachine* self);
void boxes_machine_actor_set_username_needed (BoxesMachineActor* self, gboolean needed);
gboolean boxes_display_get_need_username (BoxesDisplay* self);
static void __boxes_machine_display___lambda36__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gchar* boxes_machine_actor_get_password (BoxesMachineActor* self);
void boxes_display_set_password (BoxesDisplay* self, const gchar* value);
static void boxes_machine_finalize (GObject* obj);
static void _vala_boxes_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define BOXES_MACHINE_ACTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorPrivate))
enum  {
	BOXES_MACHINE_ACTOR_DUMMY_PROPERTY,
	BOXES_MACHINE_ACTOR_ACTOR
};
static Block16Data* block16_data_ref (Block16Data* _data16_);
static void block16_data_unref (void * _userdata_);
BoxesUI* boxes_ui_construct (GType object_type);
gchar* boxes_collection_item_get_title (BoxesCollectionItem* self);
void boxes_get_color (const gchar* desc, GdkColor* result);
static gboolean __lambda37_ (Block16Data* _data16_, GdkEventKey* event);
static gboolean ___lambda37__gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static void boxes_machine_actor_real_ui_state_changed (BoxesUI* base);
void boxes_display_page_get_size (BoxesDisplayPage* self, gint* width, gint* height);
static void _____lambda83_ (BoxesMachineActor* self);
void boxes_display_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
static void ______lambda83__clutter_actor_transitions_completed (ClutterActor* _sender, gpointer self);
void boxes_display_page_show (BoxesDisplayPage* self);
static Block17Data* block17_data_ref (Block17Data* _data17_);
static void block17_data_unref (void * _userdata_);
gboolean boxes_app_get_fullscreen (BoxesApp* self);
static void ___lambda84_ (Block17Data* _data17_);
static void ____lambda84__clutter_actor_transitions_completed (ClutterActor* _sender, gpointer self);
static void ___lambda85_ (Block17Data* _data17_, GtkAllocation* alloc);
static Block18Data* block18_data_ref (Block18Data* _data18_);
static void block18_data_unref (void * _userdata_);
static gboolean __lambda86_ (Block18Data* _data18_);
static gboolean ___lambda86__gsource_func (gpointer self);
static void ____lambda85__gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self);
static void boxes_machine_actor_finalize (GObject* obj);
static void _vala_boxes_machine_actor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


GType boxes_machine_machine_state_get_type (void) {
	static volatile gsize boxes_machine_machine_state_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_machine_state_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_MACHINE_MACHINE_STATE_UNKNOWN, "BOXES_MACHINE_MACHINE_STATE_UNKNOWN", "unknown"}, {BOXES_MACHINE_MACHINE_STATE_STOPPED, "BOXES_MACHINE_MACHINE_STATE_STOPPED", "stopped"}, {BOXES_MACHINE_MACHINE_STATE_RUNNING, "BOXES_MACHINE_MACHINE_STATE_RUNNING", "running"}, {BOXES_MACHINE_MACHINE_STATE_PAUSED, "BOXES_MACHINE_MACHINE_STATE_PAUSED", "paused"}, {0, NULL, NULL}};
		GType boxes_machine_machine_state_type_id;
		boxes_machine_machine_state_type_id = g_enum_register_static ("BoxesMachineMachineState", values);
		g_once_init_leave (&boxes_machine_machine_state_type_id__volatile, boxes_machine_machine_state_type_id);
	}
	return boxes_machine_machine_state_type_id__volatile;
}


static gpointer _g_object_ref0 (gpointer self) {
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return self ? g_object_ref (self) : NULL;
#line 614 "machine.c"
}


static void __lambda87_ (BoxesMachine* self) {
	BoxesApp* _tmp0_;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp2_ == BOXES_UI_STATE_DISPLAY) {
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot_enable (self, FALSE);
#line 632 "machine.c"
	} else {
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot_enable (self, TRUE);
#line 636 "machine.c"
	}
}


static void ___lambda87__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	__lambda87_ (self);
#line 644 "machine.c"
}


BoxesMachine* boxes_machine_construct (GType object_type, BoxesCollectionSource* source, const gchar* name) {
	BoxesMachine * self = NULL;
	const gchar* _tmp0_;
	BoxesCollectionSource* _tmp1_;
	BoxesCollectionSource* _tmp2_;
	GdkPixbuf* _tmp3_ = NULL;
	GdkPixbuf* _tmp4_;
	BoxesMachineActor* _tmp5_;
	BoxesApp* _tmp6_;
	gulong _tmp7_ = 0UL;
#line 113 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (source != NULL, NULL);
#line 113 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 113 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = (BoxesMachine*) boxes_collection_item_construct (object_type);
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = name;
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_collection_item_set_name ((BoxesCollectionItem*) self, _tmp0_);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = source;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->source);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->source = _tmp2_;
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_machine_draw_fallback_vm (BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT, FALSE);
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_set_pixbuf (self, _tmp4_);
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp4_);
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = boxes_machine_actor_new (self);
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->machine_actor);
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->machine_actor = _tmp5_;
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp6_ = boxes_app_app;
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp7_ = g_signal_connect_object ((GObject*) _tmp6_, "notify::ui-state", (GCallback) ___lambda87__g_object_notify, self, 0);
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->ui_state_id = _tmp7_;
#line 113 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return self;
#line 698 "machine.c"
}


void boxes_machine_load_screenshot (BoxesMachine* self) {
	GError * _inner_error_ = NULL;
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 706 "machine.c"
	{
		gchar* _tmp0_ = NULL;
		gchar* _tmp1_;
		GdkPixbuf* _tmp2_;
		GdkPixbuf* _tmp3_;
		GdkPixbuf* screenshot;
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp0_ = boxes_machine_get_screenshot_filename (self);
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = _tmp0_;
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp2_ = gdk_pixbuf_new_from_file (_tmp1_, &_inner_error_);
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_;
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_free0 (_tmp1_);
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		screenshot = _tmp3_;
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 727 "machine.c"
			goto __catch32_g_error;
		}
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_set_screenshot (self, screenshot, FALSE);
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (screenshot);
#line 734 "machine.c"
	}
	goto __finally32;
	__catch32_g_error:
	{
		GError* _error_ = NULL;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_error_ = _inner_error_;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_error_free0 (_error_);
#line 746 "machine.c"
	}
	__finally32:
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_inner_error_ != NULL) {
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return;
#line 757 "machine.c"
	}
}


static gboolean ___lambda50_ (BoxesMachine* self) {
	gboolean result = FALSE;
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_update_screenshot (self, FALSE, FALSE, NULL, NULL);
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = TRUE;
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 770 "machine.c"
}


static gboolean ____lambda50__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda50_ (self);
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 779 "machine.c"
}


void boxes_machine_set_screenshot_enable (BoxesMachine* self, gboolean enable) {
	gboolean _tmp0_;
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = enable;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp0_) {
#line 791 "machine.c"
		guint _tmp1_;
		BoxesApp* _tmp2_;
		GSettings* _tmp3_;
		gint _tmp4_ = 0;
		gint interval;
		gint _tmp5_;
		guint _tmp6_ = 0U;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = self->priv->screenshot_id;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_tmp1_ != ((guint) 0)) {
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			return;
#line 805 "machine.c"
		}
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_update_screenshot (self, FALSE, TRUE, NULL, NULL);
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp2_ = boxes_app_app;
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_->settings;
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp4_ = g_settings_get_int (_tmp3_, "screenshot-interval");
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		interval = _tmp4_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp5_ = interval;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp6_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) _tmp5_, ____lambda50__gsource_func, g_object_ref (self), g_object_unref);
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self->priv->screenshot_id = _tmp6_;
#line 823 "machine.c"
	} else {
		guint _tmp7_;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp7_ = self->priv->screenshot_id;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_tmp7_ != ((guint) 0)) {
#line 830 "machine.c"
			guint _tmp8_;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp8_ = self->priv->screenshot_id;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			g_source_remove (_tmp8_);
#line 836 "machine.c"
		}
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self->priv->screenshot_id = (guint) 0;
#line 840 "machine.c"
	}
}


gchar* boxes_machine_get_screenshot_filename (BoxesMachine* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_;
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_screenshot_prefix (self);
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = g_strconcat (_tmp1_, "-screenshot.png", NULL);
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = boxes_get_user_pkgcache (_tmp3_);
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = _tmp4_;
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp3_);
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp1_);
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _tmp5_;
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 875 "machine.c"
}


static void boxes_machine_real_take_screenshot_data_free (gpointer _data) {
	BoxesMachineTakeScreenshotData* _data_;
	_data_ = _data;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineTakeScreenshotData, _data_);
#line 888 "machine.c"
}


static void boxes_machine_real_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineTakeScreenshotData* _data_;
	BoxesMachine* _tmp0_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineTakeScreenshotData);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_real_take_screenshot);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_real_take_screenshot_data_free);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_real_take_screenshot_co (_data_);
#line 907 "machine.c"
}


static GdkPixbuf* boxes_machine_real_take_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
	GdkPixbuf* result;
	BoxesMachineTakeScreenshotData* _data_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return NULL;
#line 918 "machine.c"
	}
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _data_->result;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->result = NULL;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 928 "machine.c"
}


static gboolean boxes_machine_real_take_screenshot_co (BoxesMachineTakeScreenshotData* _data_) {
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case 0:
#line 937 "machine.c"
		goto _state_0;
		default:
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 942 "machine.c"
	}
	_state_0:
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->result = NULL;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 951 "machine.c"
	} else {
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 955 "machine.c"
	}
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return FALSE;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 965 "machine.c"
	} else {
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 969 "machine.c"
	}
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return FALSE;
#line 975 "machine.c"
}


void boxes_machine_take_screenshot (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->take_screenshot (self, _callback_, _user_data_);
#line 982 "machine.c"
}


GdkPixbuf* boxes_machine_take_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return BOXES_MACHINE_GET_CLASS (self)->take_screenshot_finish (self, _res_, error);
#line 989 "machine.c"
}


static GList* boxes_machine_real_get_properties (BoxesMachine* self, BoxesPropertiesPage page) {
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_machine_get_properties'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return NULL;
#line 998 "machine.c"
}


GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page) {
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return BOXES_MACHINE_GET_CLASS (self)->get_properties (self, page);
#line 1007 "machine.c"
}


static gchar* boxes_machine_real_get_screenshot_prefix (BoxesMachine* self) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_machine_get_screenshot_prefix'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return NULL;
#line 1016 "machine.c"
}


gchar* boxes_machine_get_screenshot_prefix (BoxesMachine* self) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return BOXES_MACHINE_GET_CLASS (self)->get_screenshot_prefix (self);
#line 1025 "machine.c"
}


static void boxes_machine_real_connect_display (BoxesMachine* self) {
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_machine_connect_display'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return;
#line 1034 "machine.c"
}


void boxes_machine_connect_display (BoxesMachine* self) {
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->connect_display (self);
#line 1043 "machine.c"
}


static void boxes_machine_real_disconnect_display (BoxesMachine* self) {
	BoxesDisplay* _tmp0_;
	BoxesDisplay* _tmp1_;
	BoxesApp* _tmp9_;
	BoxesDisplayPage* _tmp10_;
	GtkWidget* _tmp11_ = NULL;
	GtkWidget* _tmp12_;
	BoxesDisplay* _tmp13_;
	BoxesDisplay* _tmp14_;
	GError * _inner_error_ = NULL;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_display (self);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp1_ == NULL) {
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return;
#line 1065 "machine.c"
	}
	{
		BoxesDisplay* _tmp2_;
		BoxesDisplay* _tmp3_;
		GdkPixbuf* _tmp4_ = NULL;
		GdkPixbuf* pixbuf;
		GdkPixbuf* _tmp5_;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp2_ = boxes_machine_get_display (self);
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp4_ = boxes_display_get_pixbuf (_tmp3_, 0, &_inner_error_);
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		pixbuf = _tmp4_;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 1083 "machine.c"
			goto __catch33_g_error;
		}
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp5_ = pixbuf;
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_tmp5_ != NULL) {
#line 1090 "machine.c"
			GdkPixbuf* _tmp6_;
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp6_ = pixbuf;
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			boxes_machine_set_screenshot (self, _tmp6_, TRUE);
#line 1096 "machine.c"
		}
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (pixbuf);
#line 1100 "machine.c"
	}
	goto __finally33;
	__catch33_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp7_;
		const gchar* _tmp8_;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_error_ = _inner_error_;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp7_ = _error_;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp8_ = _tmp7_->message;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_warning ("machine.vala:178: %s", _tmp8_);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_error_free0 (_error_);
#line 1120 "machine.c"
	}
	__finally33:
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_inner_error_ != NULL) {
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return;
#line 1131 "machine.c"
	}
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp9_ = boxes_app_app;
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp10_ = _tmp9_->display_page;
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp11_ = boxes_display_page_remove_display (_tmp10_);
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp12_ = _tmp11_;
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp12_);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp13_ = boxes_machine_get_display (self);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp14_ = _tmp13_;
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_display_disconnect_it (_tmp14_);
#line 183 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_set_display (self, NULL);
#line 1151 "machine.c"
}


void boxes_machine_disconnect_display (BoxesMachine* self) {
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->disconnect_display (self);
#line 1160 "machine.c"
}


gboolean boxes_machine_is_running (BoxesMachine* self) {
	gboolean result = FALSE;
	BoxesMachineMachineState _tmp0_;
	BoxesMachineMachineState _tmp1_;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_machine_get_state (self);
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _tmp1_ == BOXES_MACHINE_MACHINE_STATE_RUNNING;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 1178 "machine.c"
}


void boxes_machine_set_screenshot (BoxesMachine* self, GdkPixbuf* large_screenshot, gboolean save) {
	GdkPixbuf* _tmp0_;
	GError * _inner_error_ = NULL;
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = large_screenshot;
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp0_ != NULL) {
#line 1191 "machine.c"
		GdkPixbuf* _tmp1_;
		gint _tmp2_ = 0;
		gint pw;
		GdkPixbuf* _tmp3_;
		gint _tmp4_ = 0;
		gint ph;
		gint _tmp5_;
		gint _tmp6_;
		gdouble _tmp7_ = 0.0;
		gdouble s;
		gint _tmp8_;
		gdouble _tmp9_;
		gint w;
		gint _tmp10_;
		gdouble _tmp11_;
		gint h;
		GdkPixbuf* _tmp12_;
		gboolean _tmp13_;
		gboolean _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		GdkPixbuf* _tmp17_;
		GdkPixbuf* small_screenshot;
		GdkPixbuf* _tmp18_;
		GdkPixbuf* _tmp19_;
		gint _tmp20_;
		gint _tmp21_;
		gdouble _tmp22_;
		gdouble _tmp23_;
		GdkPixbuf* _tmp24_;
		GdkPixbuf* _tmp25_ = NULL;
		GdkPixbuf* _tmp26_;
		BoxesMachineActor* _tmp27_;
		GdkPixbuf* _tmp28_;
		gboolean _tmp29_;
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = large_screenshot;
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp2_ = gdk_pixbuf_get_width (_tmp1_);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		pw = _tmp2_;
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp3_ = large_screenshot;
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp4_ = gdk_pixbuf_get_height (_tmp3_);
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		ph = _tmp4_;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp5_ = pw;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp6_ = ph;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp7_ = MIN (((gdouble) BOXES_MACHINE_SCREENSHOT_WIDTH) / _tmp5_, ((gdouble) BOXES_MACHINE_SCREENSHOT_HEIGHT) / _tmp6_);
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		s = _tmp7_;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp8_ = pw;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp9_ = s;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		w = (gint) (_tmp8_ * _tmp9_);
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp10_ = ph;
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp11_ = s;
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		h = (gint) (_tmp10_ * _tmp11_);
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp12_ = large_screenshot;
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp13_ = gdk_pixbuf_get_has_alpha (_tmp12_);
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp14_ = _tmp13_;
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp15_ = w;
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp16_ = h;
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp17_ = gdk_pixbuf_new (GDK_COLORSPACE_RGB, _tmp14_, 8, _tmp15_, _tmp16_);
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		small_screenshot = _tmp17_;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp18_ = large_screenshot;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp19_ = small_screenshot;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp20_ = w;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp21_ = h;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp22_ = s;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp23_ = s;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		gdk_pixbuf_scale (_tmp18_, _tmp19_, 0, 0, _tmp20_, _tmp21_, (gdouble) 0, (gdouble) 0, _tmp22_, _tmp23_, GDK_INTERP_HYPER);
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp24_ = small_screenshot;
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp25_ = boxes_machine_draw_vm (self, _tmp24_, BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT);
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp26_ = _tmp25_;
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_set_pixbuf (self, _tmp26_);
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_tmp26_);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp27_ = self->machine_actor;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp28_ = large_screenshot;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_actor_set_screenshot (_tmp27_, _tmp28_);
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp29_ = save;
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_tmp29_) {
#line 1307 "machine.c"
			{
				GdkPixbuf* _tmp30_;
				gchar* _tmp31_ = NULL;
				gchar* _tmp32_;
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp30_ = small_screenshot;
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp31_ = boxes_machine_get_screenshot_filename (self);
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp32_ = _tmp31_;
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				gdk_pixbuf_save (_tmp30_, _tmp32_, "png", &_inner_error_, NULL);
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_g_free0 (_tmp32_);
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				if (_inner_error_ != NULL) {
#line 1324 "machine.c"
					goto __catch34_g_error;
				}
			}
			goto __finally34;
			__catch34_g_error:
			{
				GError* _error_ = NULL;
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_error_ = _inner_error_;
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_inner_error_ = NULL;
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_g_error_free0 (_error_);
#line 1338 "machine.c"
			}
			__finally34:
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			if (_inner_error_ != NULL) {
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_g_object_unref0 (small_screenshot);
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				g_clear_error (&_inner_error_);
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				return;
#line 1351 "machine.c"
			}
		}
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (small_screenshot);
#line 1356 "machine.c"
	} else {
		GdkPixbuf* _tmp33_;
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp33_ = self->priv->_pixbuf;
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_tmp33_ == NULL) {
#line 1363 "machine.c"
			GdkPixbuf* _tmp34_ = NULL;
			GdkPixbuf* _tmp35_;
			BoxesMachineActor* _tmp36_;
			GdkPixbuf* _tmp37_;
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp34_ = boxes_machine_draw_fallback_vm (BOXES_MACHINE_SCREENSHOT_WIDTH, BOXES_MACHINE_SCREENSHOT_HEIGHT, FALSE);
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp35_ = _tmp34_;
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			boxes_machine_set_pixbuf (self, _tmp35_);
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_g_object_unref0 (_tmp35_);
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp36_ = self->machine_actor;
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp37_ = self->priv->_pixbuf;
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			boxes_machine_actor_set_screenshot (_tmp36_, _tmp37_);
#line 1382 "machine.c"
		}
	}
}


static void boxes_machine_update_screenshot_data_free (gpointer _data) {
	BoxesMachineUpdateScreenshotData* _data_;
	_data_ = _data;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_slice_free (BoxesMachineUpdateScreenshotData, _data_);
#line 1395 "machine.c"
}


void boxes_machine_update_screenshot (BoxesMachine* self, gboolean force_save, gboolean first_check, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMachineUpdateScreenshotData* _data_;
	BoxesMachine* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_ = g_slice_new0 (BoxesMachineUpdateScreenshotData);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_machine_update_screenshot);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_machine_update_screenshot_data_free);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->self = _tmp0_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = force_save;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->force_save = _tmp1_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = first_check;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->first_check = _tmp2_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_update_screenshot_co (_data_);
#line 1424 "machine.c"
}


void boxes_machine_update_screenshot_finish (BoxesMachine* self, GAsyncResult* _res_) {
	BoxesMachineUpdateScreenshotData* _data_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1432 "machine.c"
}


static void boxes_machine_update_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMachineUpdateScreenshotData* _data_;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_ = _user_data_;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->_source_object_ = source_object;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->_res_ = _res_;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_update_screenshot_co (_data_);
#line 1446 "machine.c"
}


static gboolean boxes_machine_update_screenshot_co (BoxesMachineUpdateScreenshotData* _data_) {
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	switch (_data_->_state_) {
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case 0:
#line 1455 "machine.c"
		goto _state_0;
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case 1:
#line 1459 "machine.c"
		goto _state_1;
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case 2:
#line 1463 "machine.c"
		goto _state_2;
		default:
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_assert_not_reached ();
#line 1468 "machine.c"
	}
	_state_0:
#line 218 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->_tmp0_ = _data_->self->priv->updating_screenshot;
#line 218 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_data_->_tmp0_) {
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_data_->_state_ == 0) {
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1479 "machine.c"
		} else {
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1483 "machine.c"
		}
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_object_unref (_data_->_async_result);
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1489 "machine.c"
	}
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->self->priv->updating_screenshot = TRUE;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->large_screenshot = NULL;
#line 1495 "machine.c"
	{
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->_state_ = 1;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_take_screenshot (_data_->self, boxes_machine_update_screenshot_ready, _data_);
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1503 "machine.c"
		_state_1:
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->_tmp1_ = NULL;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->_tmp1_ = boxes_machine_take_screenshot_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->_tmp2_ = _data_->_tmp1_;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1513 "machine.c"
			goto __catch35_g_error;
		}
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data_->large_screenshot);
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->large_screenshot = _data_->_tmp2_;
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->_tmp3_ = _data_->first_check;
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_data_->_tmp3_) {
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data_->_state_ = 2;
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			boxes_machine_take_screenshot (_data_->self, boxes_machine_update_screenshot_ready, _data_);
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			return FALSE;
#line 1530 "machine.c"
			_state_2:
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data_->_tmp4_ = NULL;
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data_->_tmp4_ = boxes_machine_take_screenshot_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data_->_tmp5_ = _data_->_tmp4_;
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			if (_data_->_inner_error_ != NULL) {
#line 1540 "machine.c"
				goto __catch35_g_error;
			}
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_g_object_unref0 (_data_->large_screenshot);
#line 230 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data_->large_screenshot = _data_->_tmp5_;
#line 1547 "machine.c"
		}
	}
	goto __finally35;
	__catch35_g_error:
	{
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->_inner_error_ = NULL;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_error_free0 (_data_->_error_);
#line 1559 "machine.c"
	}
	__finally35:
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_data_->_inner_error_ != NULL) {
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data_->large_screenshot);
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return FALSE;
#line 1572 "machine.c"
	}
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->_tmp7_ = _data_->force_save;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_data_->_tmp7_) {
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->_tmp6_ = TRUE;
#line 1580 "machine.c"
	} else {
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->_tmp8_ = _data_->self->priv->screenshot_counter;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->self->priv->screenshot_counter = _data_->_tmp8_ + 1;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data_->_tmp6_ = (_data_->_tmp8_ % 12) == 0;
#line 1588 "machine.c"
	}
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->_tmp9_ = _data_->large_screenshot;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->_tmp10_ = _data_->_tmp6_;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_set_screenshot (_data_->self, _data_->_tmp9_, _data_->_tmp10_);
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data_->self->priv->updating_screenshot = FALSE;
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_data_->large_screenshot);
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_data_->_state_ == 0) {
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1604 "machine.c"
	} else {
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1608 "machine.c"
	}
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_unref (_data_->_async_result);
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return FALSE;
#line 1614 "machine.c"
}


static GdkPixbuf* boxes_machine_draw_vm (BoxesMachine* self, GdkPixbuf* pixbuf, gint width, gint height) {
	GdkPixbuf* result = NULL;
	gint _tmp0_;
	gint _tmp1_;
	cairo_surface_t* _tmp2_;
	cairo_surface_t* surface;
	cairo_surface_t* _tmp3_;
	cairo_t* _tmp4_;
	cairo_t* context;
	GdkPixbuf* _tmp5_;
	gint _tmp6_ = 0;
	gint pw;
	GdkPixbuf* _tmp7_;
	gint _tmp8_ = 0;
	gint ph;
	gint _tmp9_;
	gint _tmp10_;
	gint x;
	gint _tmp11_;
	gint _tmp12_;
	gint y;
	cairo_t* _tmp13_;
	gint _tmp14_;
	gint _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	cairo_t* _tmp18_;
	cairo_t* _tmp19_;
	GdkPixbuf* _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
	cairo_t* _tmp23_;
	cairo_t* _tmp24_;
	gboolean _tmp25_ = FALSE;
	cairo_surface_t* _tmp37_;
	gint _tmp38_;
	gint _tmp39_;
	GdkPixbuf* _tmp40_ = NULL;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (pixbuf != NULL, NULL);
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = width;
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = height;
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp0_, _tmp1_);
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	surface = _tmp2_;
#line 241 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = surface;
#line 241 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = cairo_create (_tmp3_);
#line 241 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	context = _tmp4_;
#line 243 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = pixbuf;
#line 243 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp6_ = gdk_pixbuf_get_width (_tmp5_);
#line 243 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	pw = _tmp6_;
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp7_ = pixbuf;
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp8_ = gdk_pixbuf_get_height (_tmp7_);
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	ph = _tmp8_;
#line 245 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp9_ = width;
#line 245 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp10_ = pw;
#line 245 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	x = (_tmp9_ - _tmp10_) / 2;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp11_ = height;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp12_ = ph;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	y = (_tmp11_ - _tmp12_) / 2;
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp13_ = context;
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp14_ = x;
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp15_ = y;
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp16_ = pw;
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp17_ = ph;
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_rectangle (_tmp13_, (gdouble) _tmp14_, (gdouble) _tmp15_, (gdouble) _tmp16_, (gdouble) _tmp17_);
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp18_ = context;
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_clip (_tmp18_);
#line 251 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp19_ = context;
#line 251 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp20_ = pixbuf;
#line 251 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp21_ = x;
#line 251 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp22_ = y;
#line 251 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gdk_cairo_set_source_pixbuf (_tmp19_, _tmp20_, (gdouble) _tmp21_, (gdouble) _tmp22_);
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp23_ = context;
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_set_operator (_tmp23_, CAIRO_OPERATOR_SOURCE);
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp24_ = context;
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_paint (_tmp24_);
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp25_ = boxes_machine_is_running (self);
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (!_tmp25_) {
#line 1736 "machine.c"
		cairo_t* _tmp26_;
		cairo_t* _tmp27_;
		cairo_t* _tmp28_;
		cairo_t* _tmp29_;
		cairo_surface_t* _tmp30_;
		cairo_pattern_t* _tmp31_;
		cairo_pattern_t* grid;
		cairo_pattern_t* _tmp32_;
		cairo_t* _tmp33_;
		cairo_t* _tmp34_;
		cairo_t* _tmp35_;
		cairo_pattern_t* _tmp36_;
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp26_ = context;
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		cairo_set_source_rgba (_tmp26_, (gdouble) 1, (gdouble) 1, (gdouble) 1, (gdouble) 1);
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp27_ = context;
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		cairo_set_operator (_tmp27_, CAIRO_OPERATOR_HSL_SATURATION);
#line 258 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp28_ = context;
#line 258 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		cairo_paint (_tmp28_);
#line 260 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp29_ = context;
#line 260 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		cairo_scale (_tmp29_, 2.0, 2.0);
#line 261 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp30_ = boxes_machine_grid_surface;
#line 261 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp31_ = cairo_pattern_create_for_surface (_tmp30_);
#line 261 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		grid = _tmp31_;
#line 262 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp32_ = grid;
#line 262 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		cairo_pattern_set_extend (_tmp32_, CAIRO_EXTEND_REPEAT);
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp33_ = context;
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		cairo_set_source_rgba (_tmp33_, 0.2, 0.2, 0.2, (gdouble) 1);
#line 264 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp34_ = context;
#line 264 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		cairo_set_operator (_tmp34_, CAIRO_OPERATOR_ADD);
#line 265 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp35_ = context;
#line 265 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp36_ = grid;
#line 265 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		cairo_mask (_tmp35_, _tmp36_);
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_cairo_pattern_destroy0 (grid);
#line 1791 "machine.c"
	}
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp37_ = surface;
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp38_ = width;
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp39_ = height;
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp40_ = gdk_pixbuf_get_from_surface (_tmp37_, 0, 0, _tmp38_, _tmp39_);
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _tmp40_;
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_cairo_destroy0 (context);
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (surface);
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 1809 "machine.c"
}


static GdkPixbuf* boxes_machine_draw_fallback_vm (gint width, gint height, gboolean force) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* pixbuf;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gint _tmp2_;
	gboolean _tmp4_;
	gboolean _tmp6_;
	GdkPixbuf* _tmp43_;
	gint _tmp44_;
	gint _tmp45_;
	cairo_surface_t* _tmp46_;
	cairo_surface_t* surface;
	cairo_surface_t* _tmp47_;
	gint _tmp48_;
	gint _tmp49_;
	GdkPixbuf* _tmp50_ = NULL;
	GError * _inner_error_ = NULL;
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	pixbuf = NULL;
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = width;
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp2_ == BOXES_MACHINE_SCREENSHOT_WIDTH) {
#line 1837 "machine.c"
		gint _tmp3_;
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp3_ = height;
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = _tmp3_ == BOXES_MACHINE_SCREENSHOT_HEIGHT;
#line 1843 "machine.c"
	} else {
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = FALSE;
#line 1847 "machine.c"
	}
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp1_;
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp4_) {
#line 1853 "machine.c"
		gboolean _tmp5_;
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp5_ = force;
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp0_ = !_tmp5_;
#line 1859 "machine.c"
	} else {
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp0_ = FALSE;
#line 1863 "machine.c"
	}
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp6_ = _tmp0_;
#line 277 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp6_) {
#line 1869 "machine.c"
		GdkPixbuf* _tmp7_;
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp7_ = boxes_machine_default_fallback;
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_tmp7_ != NULL) {
#line 1875 "machine.c"
			GdkPixbuf* _tmp8_;
			GdkPixbuf* _tmp9_;
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp8_ = boxes_machine_default_fallback;
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp9_ = _g_object_ref0 (_tmp8_);
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			result = _tmp9_;
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_g_object_unref0 (pixbuf);
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			return result;
#line 1888 "machine.c"
		} else {
			gint _tmp10_;
			gint _tmp11_;
			GdkPixbuf* _tmp12_ = NULL;
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp10_ = width;
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp11_ = height;
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp12_ = boxes_machine_draw_fallback_vm (_tmp10_, _tmp11_, TRUE);
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_g_object_unref0 (boxes_machine_default_fallback);
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			boxes_machine_default_fallback = _tmp12_;
#line 1903 "machine.c"
		}
	}
	{
		gint _tmp13_;
		gint _tmp14_;
		cairo_surface_t* _tmp15_;
		cairo_surface_t* surface;
		cairo_surface_t* _tmp16_;
		cairo_t* _tmp17_;
		cairo_t* context;
		gint _tmp18_;
		gint size;
		GtkIconTheme* _tmp19_ = NULL;
		gint _tmp20_;
		GtkIconInfo* _tmp21_ = NULL;
		GtkIconInfo* icon_info;
		GtkIconInfo* _tmp22_;
		GdkPixbuf* _tmp23_ = NULL;
		GdkPixbuf* _tmp24_;
		cairo_t* _tmp25_;
		GdkPixbuf* _tmp26_;
		gint _tmp27_;
		gint _tmp28_;
		gint _tmp29_;
		gint _tmp30_;
		cairo_t* _tmp31_;
		gint _tmp32_;
		gint _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
		gint _tmp36_;
		gint _tmp37_;
		cairo_t* _tmp38_;
		cairo_surface_t* _tmp39_;
		gint _tmp40_;
		gint _tmp41_;
		GdkPixbuf* _tmp42_ = NULL;
#line 284 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp13_ = width;
#line 284 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp14_ = height;
#line 284 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp15_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp13_, _tmp14_);
#line 284 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		surface = _tmp15_;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp16_ = surface;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp17_ = cairo_create (_tmp16_);
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		context = _tmp17_;
#line 287 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp18_ = height;
#line 287 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		size = (gint) (_tmp18_ * 0.6);
#line 288 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp19_ = gtk_icon_theme_get_default ();
#line 288 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp20_ = size;
#line 288 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp21_ = gtk_icon_theme_lookup_icon (_tmp19_, "computer-symbolic", _tmp20_, GTK_ICON_LOOKUP_GENERIC_FALLBACK);
#line 288 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		icon_info = _tmp21_;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp22_ = icon_info;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp23_ = gtk_icon_info_load_icon (_tmp22_, &_inner_error_);
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp24_ = _tmp23_;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_gtk_icon_info_free0 (icon_info);
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_cairo_destroy0 (context);
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_cairo_surface_destroy0 (surface);
#line 1981 "machine.c"
			goto __catch36_g_error;
		}
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp25_ = context;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp26_ = _tmp24_;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp27_ = width;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp28_ = size;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp29_ = height;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp30_ = size;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		gdk_cairo_set_source_pixbuf (_tmp25_, _tmp26_, (gdouble) ((_tmp27_ - _tmp28_) / 2), (gdouble) ((_tmp29_ - _tmp30_) / 2));
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_tmp26_);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp31_ = context;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp32_ = width;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp33_ = size;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp34_ = height;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp35_ = size;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp36_ = size;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp37_ = size;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		cairo_rectangle (_tmp31_, (gdouble) ((_tmp32_ - _tmp33_) / 2), (gdouble) ((_tmp34_ - _tmp35_) / 2), (gdouble) _tmp36_, (gdouble) _tmp37_);
#line 293 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp38_ = context;
#line 293 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		cairo_fill (_tmp38_);
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp39_ = surface;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp40_ = width;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp41_ = height;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp42_ = gdk_pixbuf_get_from_surface (_tmp39_, 0, 0, _tmp40_, _tmp41_);
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (pixbuf);
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		pixbuf = _tmp42_;
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_gtk_icon_info_free0 (icon_info);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_cairo_destroy0 (context);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_cairo_surface_destroy0 (surface);
#line 2038 "machine.c"
	}
	goto __finally36;
	__catch36_g_error:
	{
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 2047 "machine.c"
	}
	__finally36:
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_inner_error_ != NULL) {
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (pixbuf);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return NULL;
#line 2060 "machine.c"
	}
#line 298 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp43_ = pixbuf;
#line 298 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp43_ != NULL) {
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		result = pixbuf;
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return result;
#line 2070 "machine.c"
	}
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp44_ = width;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp45_ = height;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp46_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp44_, _tmp45_);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	surface = _tmp46_;
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp47_ = surface;
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp48_ = width;
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp49_ = height;
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp50_ = gdk_pixbuf_get_from_surface (_tmp47_, 0, 0, _tmp48_, _tmp49_);
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _tmp50_;
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (surface);
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (pixbuf);
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 2096 "machine.c"
}


static void boxes_machine_real_delete (BoxesMachine* self, gboolean by_user) {
	gulong _tmp0_;
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->deleted = TRUE;
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_set_screenshot_enable (self, FALSE);
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->ui_state_id;
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 2110 "machine.c"
		BoxesApp* _tmp1_;
		gulong _tmp2_;
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = boxes_app_app;
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp2_ = self->priv->ui_state_id;
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self->priv->ui_state_id = (gulong) 0;
#line 2121 "machine.c"
	}
}


void boxes_machine_delete (BoxesMachine* self, gboolean by_user) {
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_GET_CLASS (self)->delete (self, by_user);
#line 2131 "machine.c"
}


static void boxes_machine_real_ui_state_changed (BoxesUI* base) {
	BoxesMachine * self;
	BoxesMachineActor* _tmp0_;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = (BoxesMachine*) base;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->machine_actor;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, _tmp2_);
#line 2150 "machine.c"
}


static ClutterActor* boxes_machine_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesMachine* self;
	BoxesMachineActor* _tmp0_;
	ClutterActor* _tmp1_;
	ClutterActor* _tmp2_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = (BoxesMachine*) base;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->machine_actor;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_ui_get_actor ((BoxesUI*) _tmp0_);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _tmp2_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 2172 "machine.c"
}


GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self) {
	GdkPixbuf* result;
	GdkPixbuf* _tmp0_;
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_pixbuf;
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 2187 "machine.c"
}


void boxes_machine_set_pixbuf (BoxesMachine* self, GdkPixbuf* value) {
	GdkPixbuf* _tmp0_;
	GdkPixbuf* _tmp1_;
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_pixbuf);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->_pixbuf = _tmp1_;
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "pixbuf");
#line 2206 "machine.c"
}


BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self) {
	BoxesMachineMachineState result;
	BoxesMachineMachineState _tmp0_;
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_state;
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 2221 "machine.c"
}


void boxes_machine_set_state (BoxesMachine* self, BoxesMachineMachineState value) {
	BoxesMachineMachineState _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	BoxesMachineMachineState _tmp3_;
	BoxesMachineMachineState _tmp4_;
	GEnumValue* _tmp5_;
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = value;
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->_state = _tmp0_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_machine_get_state (self);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = g_enum_get_value (g_type_class_ref (BOXES_MACHINE_TYPE_MACHINE_STATE), _tmp4_);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_debug ("machine.vala:36: State of '%s' changed to %s", _tmp2_, (_tmp5_ != NULL) ? _tmp5_->value_name : NULL);
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "state");
#line 2252 "machine.c"
}


BoxesDisplay* boxes_machine_get_display (BoxesMachine* self) {
	BoxesDisplay* result;
	BoxesDisplay* _tmp0_;
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_display;
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 2267 "machine.c"
}


static gboolean __lambda21_ (BoxesMachine* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
	GError * _inner_error_ = NULL;
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp2_ != BOXES_UI_STATE_DISPLAY) {
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		result = FALSE;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return result;
#line 2289 "machine.c"
	}
	{
		BoxesDisplay* _tmp3_;
		BoxesDisplay* _tmp4_;
		GtkWidget* _tmp5_ = NULL;
		GtkWidget* widget;
		BoxesApp* _tmp6_;
		BoxesDisplayPage* _tmp7_;
		BoxesDisplay* _tmp8_;
		BoxesDisplay* _tmp9_;
		GtkWidget* _tmp10_;
		GtkWidget* _tmp11_;
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp3_ = boxes_machine_get_display (self);
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp4_ = _tmp3_;
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp5_ = boxes_display_get_display (_tmp4_, 0, &_inner_error_);
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		widget = _tmp5_;
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 2314 "machine.c"
				goto __catch37_boxes_error;
			}
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			g_clear_error (&_inner_error_);
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			return FALSE;
#line 2323 "machine.c"
		}
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp6_ = boxes_app_app;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp7_ = _tmp6_->display_page;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp8_ = boxes_machine_get_display (self);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp9_ = _tmp8_;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp10_ = widget;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_display_page_show_display (_tmp7_, _tmp9_, _tmp10_);
#line 69 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp11_ = widget;
#line 69 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		gtk_widget_grab_focus (_tmp11_);
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (widget);
#line 2343 "machine.c"
	}
	goto __finally37;
	__catch37_boxes_error:
	{
		GError* _error_ = NULL;
		GError* _tmp12_;
		const gchar* _tmp13_;
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_error_ = _inner_error_;
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp12_ = _error_;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp13_ = _tmp12_->message;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_warning ("machine.vala:71: %s", _tmp13_);
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_error_free0 (_error_);
#line 2363 "machine.c"
	}
	__finally37:
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_inner_error_ != NULL) {
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return FALSE;
#line 2374 "machine.c"
	}
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = FALSE;
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 2380 "machine.c"
}


static gboolean ___lambda21__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda21_ (self);
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 2389 "machine.c"
}


static void _boxes_machine_display___lambda20_ (BoxesMachine* self, gint id) {
	BoxesApp* _tmp0_;
	BoxesApp* _tmp1_;
	guint _tmp2_;
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_DISPLAY);
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_app_app;
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_->duration;
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_timeout_add_full (G_PRIORITY_DEFAULT, _tmp2_, ___lambda21__gsource_func, g_object_ref (self), g_object_unref);
#line 2407 "machine.c"
}


static void __boxes_machine_display___lambda20__boxes_display_show (BoxesDisplay* _sender, gint display_id, gpointer self) {
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda20_ (self, display_id);
#line 2414 "machine.c"
}


static void _boxes_machine_display___lambda33_ (BoxesMachine* self, gint id) {
	BoxesApp* _tmp0_;
	BoxesDisplayPage* _tmp1_;
	GtkWidget* _tmp2_ = NULL;
	GtkWidget* _tmp3_;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_->display_page;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_display_page_remove_display (_tmp1_);
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (_tmp3_);
#line 2433 "machine.c"
}


static void __boxes_machine_display___lambda33__boxes_display_hide (BoxesDisplay* _sender, gint display_id, gpointer self) {
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda33_ (self, display_id);
#line 2440 "machine.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1418 "../vapi/upstream/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1419 "../vapi/upstream/glib-2.0.vapi"
	result = self;
#line 1419 "../vapi/upstream/glib-2.0.vapi"
	return result;
#line 2452 "machine.c"
}


static void _boxes_machine_display___lambda34_ (BoxesMachine* self) {
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_;
	BoxesApp* _tmp5_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = string_to_string (_tmp1_);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = g_strconcat ("display ", _tmp2_, " disconnected", NULL);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_message ("machine.vala:83: %s", _tmp4_);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp4_);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = boxes_app_app;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp5_, BOXES_UI_STATE_COLLECTION);
#line 2481 "machine.c"
}


static void __boxes_machine_display___lambda34__boxes_display_disconnected (BoxesDisplay* _sender, gpointer self) {
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda34_ (self);
#line 2488 "machine.c"
}


static void _boxes_machine_display___lambda35_ (BoxesMachine* self) {
	BoxesMachineActor* _tmp0_;
	BoxesDisplay* _tmp1_;
	BoxesDisplay* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->machine_actor;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_machine_get_display (self);
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_display_get_need_password (_tmp2_);
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_actor_set_password_needed (_tmp0_, _tmp4_);
#line 2510 "machine.c"
}


static void __boxes_machine_display___lambda35__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 87 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda35_ (self);
#line 2517 "machine.c"
}


static void _boxes_machine_display___lambda36_ (BoxesMachine* self) {
	BoxesMachineActor* _tmp0_;
	BoxesDisplay* _tmp1_;
	BoxesDisplay* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->machine_actor;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_machine_get_display (self);
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = boxes_display_get_need_username (_tmp2_);
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = _tmp3_;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_actor_set_username_needed (_tmp0_, _tmp4_);
#line 2539 "machine.c"
}


static void __boxes_machine_display___lambda36__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_boxes_machine_display___lambda36_ (self);
#line 2546 "machine.c"
}


void boxes_machine_set_display (BoxesMachine* self, BoxesDisplay* value) {
	BoxesDisplay* _tmp0_;
	BoxesDisplay* _tmp11_;
	BoxesDisplay* _tmp12_;
	BoxesDisplay* _tmp13_;
	BoxesDisplay* _tmp14_;
	gulong _tmp15_ = 0UL;
	BoxesDisplay* _tmp16_;
	gulong _tmp17_ = 0UL;
	BoxesDisplay* _tmp18_;
	gulong _tmp19_ = 0UL;
	BoxesDisplay* _tmp20_;
	gulong _tmp21_ = 0UL;
	BoxesDisplay* _tmp22_;
	gulong _tmp23_ = 0UL;
	BoxesDisplay* _tmp24_;
	BoxesMachineActor* _tmp25_;
	gchar* _tmp26_ = NULL;
	gchar* _tmp27_;
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->_display;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp0_ != NULL) {
#line 2575 "machine.c"
		BoxesDisplay* _tmp1_;
		gulong _tmp2_;
		BoxesDisplay* _tmp3_;
		gulong _tmp4_;
		BoxesDisplay* _tmp5_;
		gulong _tmp6_;
		BoxesDisplay* _tmp7_;
		gulong _tmp8_;
		BoxesDisplay* _tmp9_;
		gulong _tmp10_;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = self->priv->_display;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp2_ = self->priv->show_id;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self->priv->show_id = (gulong) 0;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp3_ = self->priv->_display;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp4_ = self->priv->hide_id;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self->priv->hide_id = (gulong) 0;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp5_ = self->priv->_display;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp6_ = self->priv->disconnected_id;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp5_, _tmp6_);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self->priv->disconnected_id = (gulong) 0;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp7_ = self->priv->_display;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp8_ = self->priv->need_password_id;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp7_, _tmp8_);
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self->priv->need_password_id = (gulong) 0;
#line 53 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp9_ = self->priv->_display;
#line 53 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp10_ = self->priv->need_username_id;
#line 53 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp9_, _tmp10_);
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self->priv->need_username_id = (gulong) 0;
#line 2626 "machine.c"
	}
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp11_ = value;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp12_ = _g_object_ref0 (_tmp11_);
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_display);
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->_display = _tmp12_;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp13_ = self->priv->_display;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp13_ == NULL) {
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return;
#line 2642 "machine.c"
	}
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp14_ = self->priv->_display;
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp15_ = g_signal_connect_object (_tmp14_, "show", (GCallback) __boxes_machine_display___lambda20__boxes_display_show, self, 0);
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->show_id = _tmp15_;
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp16_ = self->priv->_display;
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp17_ = g_signal_connect_object (_tmp16_, "hide", (GCallback) __boxes_machine_display___lambda33__boxes_display_hide, self, 0);
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->hide_id = _tmp17_;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp18_ = self->priv->_display;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp19_ = g_signal_connect_object (_tmp18_, "disconnected", (GCallback) __boxes_machine_display___lambda34__boxes_display_disconnected, self, 0);
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->disconnected_id = _tmp19_;
#line 87 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp20_ = self->priv->_display;
#line 87 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp21_ = g_signal_connect_object ((GObject*) _tmp20_, "notify::need-password", (GCallback) __boxes_machine_display___lambda35__g_object_notify, self, 0);
#line 87 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->need_password_id = _tmp21_;
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp22_ = self->priv->_display;
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp23_ = g_signal_connect_object ((GObject*) _tmp22_, "notify::need-username", (GCallback) __boxes_machine_display___lambda36__g_object_notify, self, 0);
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->need_username_id = _tmp23_;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp24_ = self->priv->_display;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp25_ = self->machine_actor;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp26_ = boxes_machine_actor_get_password (_tmp25_);
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp27_ = _tmp26_;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_display_set_password (_tmp24_, _tmp27_);
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp27_);
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_notify ((GObject *) self, "display");
#line 2688 "machine.c"
}


static void boxes_machine_class_init (BoxesMachineClass * klass) {
	cairo_surface_t* _tmp0_;
	cairo_surface_t* _tmp1_;
	cairo_t* _tmp2_;
	cairo_t* cr;
	cairo_t* _tmp3_;
	cairo_t* _tmp4_;
	cairo_t* _tmp5_;
	cairo_t* _tmp6_;
	cairo_t* _tmp7_;
	cairo_t* _tmp8_;
	cairo_t* _tmp9_;
	cairo_t* _tmp10_;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_type_class_add_private (klass, sizeof (BoxesMachinePrivate));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->take_screenshot = boxes_machine_real_take_screenshot;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->take_screenshot_finish = boxes_machine_real_take_screenshot_finish;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->get_properties = boxes_machine_real_get_properties;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->get_screenshot_prefix = boxes_machine_real_get_screenshot_prefix;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->connect_display = boxes_machine_real_connect_display;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->disconnect_display = boxes_machine_real_disconnect_display;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_MACHINE_CLASS (klass)->delete = boxes_machine_real_delete;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_machine_real_ui_state_changed;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_machine_real_get_actor;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_machine_get_property;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_machine_set_property;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_machine_finalize;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_PIXBUF, g_param_spec_object ("pixbuf", "pixbuf", "pixbuf", GDK_TYPE_PIXBUF, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_STATE, g_param_spec_enum ("state", "state", "state", BOXES_MACHINE_TYPE_MACHINE_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_DISPLAY, g_param_spec_object ("display", "display", "display", BOXES_TYPE_DISPLAY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = cairo_image_surface_create (CAIRO_FORMAT_A8, 2, 2);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_cairo_surface_destroy0 (boxes_machine_grid_surface);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_grid_surface = _tmp0_;
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = boxes_machine_grid_surface;
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = cairo_create (_tmp1_);
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cr = _tmp2_;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = cr;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_set_source_rgba (_tmp3_, (gdouble) 0, (gdouble) 0, (gdouble) 0, (gdouble) 0);
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = cr;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_paint (_tmp4_);
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = cr;
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_set_source_rgba (_tmp5_, (gdouble) 1, (gdouble) 1, (gdouble) 1, (gdouble) 1);
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp6_ = cr;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_set_operator (_tmp6_, CAIRO_OPERATOR_SOURCE);
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp7_ = cr;
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_rectangle (_tmp7_, (gdouble) 0, (gdouble) 0, (gdouble) 1, (gdouble) 1);
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp8_ = cr;
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_fill (_tmp8_);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp9_ = cr;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_rectangle (_tmp9_, (gdouble) 1, (gdouble) 1, (gdouble) 1, (gdouble) 1);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp10_ = cr;
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	cairo_fill (_tmp10_);
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_cairo_destroy0 (cr);
#line 2787 "machine.c"
}


static void boxes_machine_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	iface->get_properties = (GList* (*)(BoxesIPropertiesProvider*, BoxesPropertiesPage)) boxes_machine_get_properties;
#line 2796 "machine.c"
}


static void boxes_machine_instance_init (BoxesMachine * self) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv = BOXES_MACHINE_GET_PRIVATE (self);
#line 2803 "machine.c"
}


static void boxes_machine_finalize (GObject* obj) {
	BoxesMachine * self;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_MACHINE, BoxesMachine);
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->machine_actor);
#line 9 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->source);
#line 10 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->config);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_pixbuf);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->_display);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (boxes_machine_parent_class)->finalize (obj);
#line 2823 "machine.c"
}


GType boxes_machine_get_type (void) {
	static volatile gsize boxes_machine_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesMachineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_machine_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesMachine), 0, (GInstanceInitFunc) boxes_machine_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_machine_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_machine_type_id;
		boxes_machine_type_id = g_type_register_static (BOXES_TYPE_COLLECTION_ITEM, "BoxesMachine", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (boxes_machine_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_machine_type_id__volatile, boxes_machine_type_id);
	}
	return boxes_machine_type_id__volatile;
}


static void _vala_boxes_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MACHINE, BoxesMachine);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	switch (property_id) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_ACTOR:
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_PIXBUF:
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_machine_get_pixbuf (self));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_STATE:
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_value_set_enum (value, boxes_machine_get_state (self));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_DISPLAY:
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_machine_get_display (self));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 2870 "machine.c"
		default:
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 2876 "machine.c"
	}
}


static void _vala_boxes_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MACHINE, BoxesMachine);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	switch (property_id) {
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_PIXBUF:
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_set_pixbuf (self, g_value_get_object (value));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_STATE:
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_set_state (self, g_value_get_enum (value));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_DISPLAY:
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_set_display (self, g_value_get_object (value));
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 2904 "machine.c"
		default:
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 2910 "machine.c"
	}
}


static Block16Data* block16_data_ref (Block16Data* _data16_) {
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_atomic_int_inc (&_data16_->_ref_count_);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return _data16_;
#line 2920 "machine.c"
}


static void block16_data_unref (void * _userdata_) {
	Block16Data* _data16_;
	_data16_ = (Block16Data*) _userdata_;
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (g_atomic_int_dec_and_test (&_data16_->_ref_count_)) {
#line 2929 "machine.c"
		BoxesMachineActor * self;
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self = _data16_->self;
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (_data16_->machine);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_slice_free (Block16Data, _data16_);
#line 2939 "machine.c"
	}
}


static gboolean __lambda37_ (Block16Data* _data16_, GdkEventKey* event) {
	BoxesMachineActor * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GdkEventKey _tmp2_;
	guint _tmp3_;
	gboolean _tmp6_;
	gboolean _tmp9_;
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = _data16_->self;
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = *event;
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_.keyval;
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp3_ == ((guint) GDK_KEY_KP_Enter)) {
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = TRUE;
#line 2965 "machine.c"
	} else {
		GdkEventKey _tmp4_;
		guint _tmp5_;
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp4_ = *event;
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp5_ = _tmp4_.keyval;
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = _tmp5_ == ((guint) GDK_KEY_ISO_Enter);
#line 2975 "machine.c"
	}
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp6_ = _tmp1_;
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp6_) {
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp0_ = TRUE;
#line 2983 "machine.c"
	} else {
		GdkEventKey _tmp7_;
		guint _tmp8_;
#line 376 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp7_ = *event;
#line 376 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp8_ = _tmp7_.keyval;
#line 376 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp0_ = _tmp8_ == ((guint) GDK_KEY_Return);
#line 2993 "machine.c"
	}
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp0_;
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp9_) {
#line 2999 "machine.c"
		BoxesMachine* _tmp10_;
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp10_ = _data16_->machine;
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_connect_display (_tmp10_);
#line 379 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		result = TRUE;
#line 379 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return result;
#line 3009 "machine.c"
	}
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = FALSE;
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 3015 "machine.c"
}


static gboolean ___lambda37__gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = __lambda37_ (self, event);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 3024 "machine.c"
}


BoxesMachineActor* boxes_machine_actor_construct (GType object_type, BoxesMachine* machine) {
	BoxesMachineActor * self = NULL;
	Block16Data* _data16_;
	BoxesMachine* _tmp0_;
	BoxesMachine* _tmp1_;
	BoxesMachine* _tmp2_;
	BoxesMachine* _tmp3_;
	ClutterBoxLayout* _tmp4_;
	ClutterBoxLayout* layout;
	ClutterActor* _tmp5_;
	ClutterActor* _tmp6_;
	GtkClutterTexture* _tmp7_;
	GtkClutterTexture* _tmp8_;
	BoxesMachine* _tmp9_;
	GdkPixbuf* _tmp10_;
	GdkPixbuf* _tmp11_;
	ClutterActor* _tmp12_;
	ClutterActor* _tmp13_;
	GtkClutterTexture* _tmp14_;
	ClutterActor* _tmp15_;
	GtkClutterTexture* _tmp16_;
	GtkVBox* _tmp17_;
	GtkVBox* _tmp18_;
	GtkClutterActor* _tmp19_;
	GtkClutterActor* _tmp20_;
	GtkClutterActor* _tmp21_;
	GtkWidget* _tmp22_ = NULL;
	GtkStyleContext* _tmp23_ = NULL;
	BoxesMachine* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	GtkLabel* _tmp28_;
	GtkLabel* _tmp29_;
	GdkColor _tmp30_ = {0};
	BoxesMachine* _tmp31_;
	GtkLabel* _tmp32_;
	GtkVBox* _tmp33_;
	GtkLabel* _tmp34_;
	GtkVBox* _tmp35_;
	GtkEntry* _tmp36_;
	GtkEntry* _tmp37_;
	GtkEntry* _tmp38_;
	const gchar* _tmp39_ = NULL;
	GtkEntry* _tmp40_;
	GtkVBox* _tmp41_;
	GtkEntry* _tmp42_;
	GtkVBox* _tmp43_;
	GtkEntry* _tmp44_;
	ClutterActor* _tmp45_;
	GtkClutterActor* _tmp46_;
	ClutterActor* _tmp47_;
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data16_ = g_slice_new0 (Block16Data);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data16_->_ref_count_ = 1;
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = machine;
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data16_->machine = _tmp1_;
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = (BoxesMachineActor*) boxes_ui_construct (object_type);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data16_->self = g_object_ref (self);
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _data16_->machine;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->machine);
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->machine = _tmp3_;
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = (ClutterBoxLayout*) clutter_box_layout_new ();
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp4_);
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	layout = _tmp4_;
#line 343 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_box_layout_set_vertical (layout, TRUE);
#line 344 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_box_layout_set_spacing (layout, (guint) 10);
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = clutter_actor_new ();
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp5_);
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->_actor);
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->_actor = _tmp5_;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp6_ = self->_actor;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_set_layout_manager (_tmp6_, (ClutterLayoutManager*) layout);
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp7_ = (GtkClutterTexture*) gtk_clutter_texture_new ();
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp7_);
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->screenshot);
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->screenshot = _tmp7_;
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp8_ = self->priv->screenshot;
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp8_, "screenshot");
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp9_ = _data16_->machine;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp10_ = boxes_machine_get_pixbuf (_tmp9_);
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp11_ = _tmp10_;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_actor_set_screenshot (self, _tmp11_);
#line 351 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp12_ = self->_actor;
#line 351 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp13_ = self->_actor;
#line 351 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_set (_tmp13_, "natural-width", (gfloat) BOXES_MACHINE_SCREENSHOT_WIDTH, NULL);
#line 351 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_set (_tmp12_, "min-width", (gfloat) BOXES_MACHINE_SCREENSHOT_WIDTH, NULL);
#line 353 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp14_ = self->priv->screenshot;
#line 353 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_texture_set_keep_aspect_ratio ((ClutterTexture*) _tmp14_, TRUE);
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp15_ = self->_actor;
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp16_ = self->priv->screenshot;
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_container_add ((ClutterContainer*) _tmp15_, (ClutterActor*) _tmp16_, NULL);
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp17_ = (GtkVBox*) gtk_vbox_new (FALSE, 0);
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp17_);
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->vbox);
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->vbox = _tmp17_;
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp18_ = self->priv->vbox;
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp19_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp18_);
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp19_);
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->gtk_vbox);
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->gtk_vbox = _tmp19_;
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp20_ = self->priv->gtk_vbox;
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_set_height ((ClutterActor*) _tmp20_, (gfloat) 80);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp21_ = self->priv->gtk_vbox;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp22_ = gtk_clutter_actor_get_widget (_tmp21_);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp23_ = gtk_widget_get_style_context (_tmp22_);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_style_context_add_class (_tmp23_, "boxes-bg");
#line 364 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp24_ = _data16_->machine;
#line 364 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp25_ = boxes_collection_item_get_title ((BoxesCollectionItem*) _tmp24_);
#line 364 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp26_ = _tmp25_;
#line 364 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp27_ = _tmp26_;
#line 364 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp28_ = (GtkLabel*) gtk_label_new (_tmp27_);
#line 364 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp28_);
#line 364 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->label);
#line 364 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->label = _tmp28_;
#line 364 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_free0 (_tmp27_);
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp29_ = self->priv->label;
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_get_color ("white", &_tmp30_);
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_widget_modify_fg ((GtkWidget*) _tmp29_, GTK_STATE_NORMAL, &_tmp30_);
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp31_ = _data16_->machine;
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp32_ = self->priv->label;
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp31_, "title", (GObject*) _tmp32_, "label", G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp33_ = self->priv->vbox;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp34_ = self->priv->label;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_container_add ((GtkContainer*) _tmp33_, (GtkWidget*) _tmp34_);
#line 368 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp35_ = self->priv->vbox;
#line 368 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp35_, GTK_ALIGN_START);
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp36_ = (GtkEntry*) gtk_entry_new ();
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_ref_sink (_tmp36_);
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->password_entry = _tmp36_;
#line 370 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp37_ = self->priv->password_entry;
#line 370 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_entry_set_visibility (_tmp37_, FALSE);
#line 371 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp38_ = self->priv->password_entry;
#line 371 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp39_ = _ ("Password");
#line 371 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_entry_set_placeholder_text (_tmp38_, _tmp39_);
#line 372 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_actor_set_password_needed (self, FALSE);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp40_ = self->priv->password_entry;
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_signal_connect_data ((GtkWidget*) _tmp40_, "key-press-event", (GCallback) ___lambda37__gtk_widget_key_press_event, block16_data_ref (_data16_), (GClosureNotify) block16_data_unref, 0);
#line 384 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp41_ = self->priv->vbox;
#line 384 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp42_ = self->priv->password_entry;
#line 384 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_container_add ((GtkContainer*) _tmp41_, (GtkWidget*) _tmp42_);
#line 386 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp43_ = self->priv->vbox;
#line 386 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp43_);
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp44_ = self->priv->password_entry;
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_widget_hide ((GtkWidget*) _tmp44_);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp45_ = self->_actor;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp46_ = self->priv->gtk_vbox;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_container_add ((ClutterContainer*) _tmp45_, (ClutterActor*) _tmp46_, NULL);
#line 390 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp47_ = self->_actor;
#line 390 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_set_reactive (_tmp47_, TRUE);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (layout);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	block16_data_unref (_data16_);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data16_ = NULL;
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return self;
#line 3290 "machine.c"
}


BoxesMachineActor* boxes_machine_actor_new (BoxesMachine* machine) {
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return boxes_machine_actor_construct (BOXES_TYPE_MACHINE_ACTOR, machine);
#line 3297 "machine.c"
}


void boxes_machine_actor_set_screenshot (BoxesMachineActor* self, GdkPixbuf* pixbuf) {
	GError * _inner_error_ = NULL;
#line 393 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 393 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (pixbuf != NULL);
#line 3307 "machine.c"
	{
		GtkClutterTexture* _tmp0_;
		GdkPixbuf* _tmp1_;
#line 395 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp0_ = self->priv->screenshot;
#line 395 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = pixbuf;
#line 395 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		gtk_clutter_texture_set_from_pixbuf (_tmp0_, _tmp1_, &_inner_error_);
#line 395 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		if (_inner_error_ != NULL) {
#line 3319 "machine.c"
			goto __catch38_g_error;
		}
	}
	goto __finally38;
	__catch38_g_error:
	{
		GError* err = NULL;
		GError* _tmp2_;
		const gchar* _tmp3_;
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		err = _inner_error_;
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_inner_error_ = NULL;
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp2_ = err;
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_->message;
#line 397 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_warning ("machine.vala:397: %s", _tmp3_);
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_error_free0 (err);
#line 3341 "machine.c"
	}
	__finally38:
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_inner_error_ != NULL) {
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_clear_error (&_inner_error_);
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		return;
#line 3352 "machine.c"
	}
}


void boxes_machine_actor_set_password_needed (BoxesMachineActor* self, gboolean needed) {
	ClutterActor* _tmp0_;
	GtkEntry* _tmp1_;
	gboolean _tmp2_;
	GtkEntry* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
#line 401 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 402 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->_actor;
#line 402 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_queue_relayout (_tmp0_);
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = self->priv->password_entry;
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = needed;
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp1_, _tmp2_);
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = self->priv->password_entry;
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = needed;
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_widget_set_can_focus ((GtkWidget*) _tmp3_, _tmp4_);
#line 405 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = needed;
#line 405 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp5_) {
#line 3386 "machine.c"
		GtkEntry* _tmp6_;
		BoxesMachine* _tmp7_;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp6_ = self->priv->password_entry;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		gtk_widget_grab_focus ((GtkWidget*) _tmp6_);
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp7_ = self->priv->machine;
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_set_display (_tmp7_, NULL);
#line 3397 "machine.c"
	}
}


void boxes_machine_actor_set_username_needed (BoxesMachineActor* self, gboolean needed) {
	gboolean _tmp0_;
#line 411 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (self != NULL);
#line 412 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_debug ("machine.vala:412: FIXME: Do something about fetching username when req" \
"uired?");
#line 413 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = needed;
#line 413 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp0_) {
#line 3412 "machine.c"
		BoxesMachine* _tmp1_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = self->priv->machine;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		boxes_machine_set_display (_tmp1_, NULL);
#line 3418 "machine.c"
	}
}


gchar* boxes_machine_actor_get_password (BoxesMachineActor* self) {
	gchar* result = NULL;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
#line 417 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->password_entry;
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _tmp3_;
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 3443 "machine.c"
}


static void _____lambda83_ (BoxesMachineActor* self) {
	GtkClutterActor* _tmp0_;
	GtkWidget* _tmp1_ = NULL;
	GtkWidget* _tmp2_;
	GtkWidget* widget;
	GtkClutterActor* _tmp3_;
	GtkClutterActor* _tmp4_;
	BoxesMachine* _tmp5_;
	BoxesDisplay* _tmp6_;
	BoxesDisplay* _tmp7_;
	BoxesApp* _tmp8_;
	BoxesDisplayPage* _tmp9_;
	BoxesMachine* _tmp10_;
	BoxesDisplay* _tmp11_;
	BoxesDisplay* _tmp12_;
#line 455 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->display;
#line 455 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_get (_tmp0_, "contents", &_tmp1_, NULL);
#line 455 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = _tmp1_;
#line 455 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	widget = _tmp2_;
#line 456 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = self->priv->display;
#line 456 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_set (_tmp3_, "contents", NULL, NULL);
#line 457 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = self->priv->display;
#line 457 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_destroy ((ClutterActor*) _tmp4_);
#line 458 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->display);
#line 458 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->display = NULL;
#line 460 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = self->priv->machine;
#line 460 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp6_ = boxes_machine_get_display (_tmp5_);
#line 460 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp7_ = _tmp6_;
#line 460 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_display_set_enable_inputs (_tmp7_, widget, TRUE);
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp8_ = boxes_app_app;
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp9_ = _tmp8_->display_page;
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp10_ = self->priv->machine;
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp11_ = boxes_machine_get_display (_tmp10_);
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp12_ = _tmp11_;
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_display_page_show_display (_tmp9_, _tmp12_, widget);
#line 454 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (widget);
#line 3504 "machine.c"
}


static void ______lambda83__clutter_actor_transitions_completed (ClutterActor* _sender, gpointer self) {
#line 454 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_____lambda83_ (self);
#line 3511 "machine.c"
}


static Block17Data* block17_data_ref (Block17Data* _data17_) {
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_atomic_int_inc (&_data17_->_ref_count_);
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return _data17_;
#line 3520 "machine.c"
}


static void block17_data_unref (void * _userdata_) {
	Block17Data* _data17_;
	_data17_ = (Block17Data*) _userdata_;
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (g_atomic_int_dec_and_test (&_data17_->_ref_count_)) {
#line 3529 "machine.c"
		BoxesMachineActor * self;
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self = _data17_->self;
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_g_object_unref0 (self);
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_slice_free (Block17Data, _data17_);
#line 3537 "machine.c"
	}
}


static void ___lambda84_ (Block17Data* _data17_) {
	BoxesMachineActor * self;
	GtkClutterActor* _tmp0_;
	gulong _tmp1_;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = _data17_->self;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->display;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = _data17_->completed_id;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data17_->completed_zoom = TRUE;
#line 3556 "machine.c"
}


static void ____lambda84__clutter_actor_transitions_completed (ClutterActor* _sender, gpointer self) {
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	___lambda84_ (self);
#line 3563 "machine.c"
}


static Block18Data* block18_data_ref (Block18Data* _data18_) {
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_atomic_int_inc (&_data18_->_ref_count_);
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return _data18_;
#line 3572 "machine.c"
}


static void block18_data_unref (void * _userdata_) {
	Block18Data* _data18_;
	_data18_ = (Block18Data*) _userdata_;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (g_atomic_int_dec_and_test (&_data18_->_ref_count_)) {
#line 3581 "machine.c"
		BoxesMachineActor * self;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		self = _data18_->_data17_->self;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		block17_data_unref (_data18_->_data17_);
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_data18_->_data17_ = NULL;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_slice_free (Block18Data, _data18_);
#line 3591 "machine.c"
	}
}


static gboolean __lambda86_ (Block18Data* _data18_) {
	Block17Data* _data17_;
	BoxesMachineActor * self;
	gboolean result = FALSE;
	BoxesApp* _tmp0_;
	BoxesTopbar* _tmp1_;
	ClutterActor* _tmp2_;
	ClutterActor* _tmp3_;
	BoxesApp* _tmp4_;
	ClutterBinLayout* _tmp5_;
	GtkClutterActor* _tmp6_;
	GtkClutterActor* _tmp7_;
	GtkClutterActor* _tmp8_;
	GtkAllocation _tmp9_;
	gint _tmp10_;
	GtkClutterActor* _tmp11_;
	GtkAllocation _tmp12_;
	gint _tmp13_;
	GtkClutterActor* _tmp14_;
	GtkAllocation _tmp15_;
	gint _tmp16_;
	GtkClutterActor* _tmp17_;
	GtkAllocation _tmp18_;
	gint _tmp19_;
	gboolean _tmp20_;
#line 501 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data17_ = _data18_->_data17_;
#line 501 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = _data17_->self;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_->topbar;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp2_ = boxes_ui_get_actor ((BoxesUI*) _tmp1_);
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp3_ = _tmp2_;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_show (_tmp3_);
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = boxes_app_app;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = _tmp4_->overlay_bin;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp6_ = self->priv->display;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_bin_layout_set_alignment (_tmp5_, (ClutterActor*) _tmp6_, CLUTTER_BIN_ALIGNMENT_FIXED, CLUTTER_BIN_ALIGNMENT_FIXED);
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp7_ = self->priv->display;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_set_easing_duration ((ClutterActor*) _tmp7_, (guint) 0);
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp8_ = self->priv->display;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp9_ = _data18_->alloc;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp10_ = _tmp9_.x;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_set_x ((ClutterActor*) _tmp8_, (gfloat) _tmp10_);
#line 510 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp11_ = self->priv->display;
#line 510 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp12_ = _data18_->alloc;
#line 510 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp13_ = _tmp12_.y;
#line 510 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_set_y ((ClutterActor*) _tmp11_, (gfloat) _tmp13_);
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp14_ = self->priv->display;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp15_ = _data18_->alloc;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp16_ = _tmp15_.width;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_set_width ((ClutterActor*) _tmp14_, (gfloat) _tmp16_);
#line 512 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp17_ = self->priv->display;
#line 512 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp18_ = _data18_->alloc;
#line 512 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp19_ = _tmp18_.height;
#line 512 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	clutter_actor_set_height ((ClutterActor*) _tmp17_, (gfloat) _tmp19_);
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp20_ = _data17_->completed_zoom;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (!_tmp20_) {
#line 3683 "machine.c"
		GtkClutterActor* _tmp21_;
		BoxesApp* _tmp22_;
		guint _tmp23_;
#line 515 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp21_ = self->priv->display;
#line 515 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp22_ = boxes_app_app;
#line 515 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp23_ = _tmp22_->duration;
#line 515 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		clutter_actor_set_easing_duration ((ClutterActor*) _tmp21_, _tmp23_);
#line 3695 "machine.c"
	}
#line 517 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = FALSE;
#line 517 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 3701 "machine.c"
}


static gboolean ___lambda86__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda86_ (self);
#line 501 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 3710 "machine.c"
}


static void ___lambda85_ (Block17Data* _data17_, GtkAllocation* alloc) {
	BoxesMachineActor * self;
	Block18Data* _data18_;
	GtkAllocation _tmp0_;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = _data17_->self;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_return_if_fail (alloc != NULL);
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data18_ = g_slice_new0 (Block18Data);
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data18_->_ref_count_ = 1;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data18_->_data17_ = block17_data_ref (_data17_);
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = *alloc;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data18_->alloc = _tmp0_;
#line 501 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_idle_add_full (G_PRIORITY_HIGH, ___lambda86__gsource_func, block18_data_ref (_data18_), block18_data_unref);
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	block18_data_unref (_data18_);
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_data18_ = NULL;
#line 3738 "machine.c"
}


static void ____lambda85__gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self) {
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	___lambda85_ (self, allocation);
#line 3745 "machine.c"
}


static void boxes_machine_actor_real_ui_state_changed (BoxesUI* base) {
	BoxesMachineActor * self;
	gint window_width = 0;
	gint window_height = 0;
	gint width = 0;
	gint height = 0;
	gint x = 0;
	gint y = 0;
	BoxesApp* _tmp0_;
	BoxesDisplayPage* _tmp1_;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	BoxesApp* _tmp4_;
	GtkApplicationWindow* _tmp5_;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	gint _tmp8_;
	gint _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	BoxesUIState _tmp12_;
	BoxesUIState _tmp13_;
#line 421 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = (BoxesMachineActor*) base;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = boxes_app_app;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp1_ = _tmp0_->display_page;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_display_page_get_size (_tmp1_, &_tmp2_, &_tmp3_);
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	width = _tmp2_;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	height = _tmp3_;
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp4_ = boxes_app_app;
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp5_ = _tmp4_->window;
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	gtk_window_get_size ((GtkWindow*) _tmp5_, &_tmp6_, &_tmp7_);
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	window_width = _tmp6_;
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	window_height = _tmp7_;
#line 428 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp8_ = window_width;
#line 428 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp9_ = width;
#line 428 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	x = _tmp8_ - _tmp9_;
#line 429 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp10_ = window_height;
#line 429 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp11_ = height;
#line 429 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	y = _tmp10_ - _tmp11_;
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp12_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp13_ = _tmp12_;
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	switch (_tmp13_) {
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_CREDS:
#line 3813 "machine.c"
		{
			GtkClutterActor* _tmp14_;
#line 433 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp14_ = self->priv->gtk_vbox;
#line 433 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			clutter_actor_show ((ClutterActor*) _tmp14_);
#line 434 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			break;
#line 3822 "machine.c"
		}
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 3826 "machine.c"
		{
			GtkClutterActor* _tmp15_;
			BoxesUIState _tmp16_;
#line 437 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp15_ = self->priv->gtk_vbox;
#line 437 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			clutter_actor_hide ((ClutterActor*) _tmp15_);
#line 438 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp16_ = ((BoxesUI*) self)->previous_ui_state;
#line 438 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			if (_tmp16_ == BOXES_UI_STATE_CREDS) {
#line 3838 "machine.c"
				BoxesApp* _tmp17_;
				ClutterBinLayout* _tmp18_;
				ClutterActor* _tmp19_;
				ClutterActor* _tmp20_;
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp17_ = boxes_app_app;
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp18_ = _tmp17_->overlay_bin;
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp19_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp20_ = _tmp19_;
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				clutter_bin_layout_set_alignment (_tmp18_, _tmp20_, CLUTTER_BIN_ALIGNMENT_FILL, CLUTTER_BIN_ALIGNMENT_FILL);
#line 3853 "machine.c"
			} else {
				GtkClutterActor* _tmp21_;
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp21_ = self->priv->display;
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				if (_tmp21_ != NULL) {
#line 3860 "machine.c"
					BoxesApp* _tmp22_;
					BoxesProperties* _tmp23_;
					GtkWidget* _tmp24_;
					gulong _tmp25_;
					GtkClutterActor* _tmp26_;
					BoxesApp* _tmp27_;
					guint _tmp28_;
					BoxesApp* _tmp29_;
					ClutterBinLayout* _tmp30_;
					GtkClutterActor* _tmp31_;
					GtkClutterActor* _tmp32_;
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp22_ = boxes_app_app;
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp23_ = _tmp22_->properties;
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp24_ = _tmp23_->screenshot_placeholder;
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp25_ = self->priv->track_screenshot_id;
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					g_signal_handler_disconnect ((GObject*) _tmp24_, _tmp25_);
#line 447 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					self->priv->track_screenshot_id = (gulong) 0;
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp26_ = self->priv->display;
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp27_ = boxes_app_app;
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp28_ = _tmp27_->duration;
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					clutter_actor_set_easing_duration ((ClutterActor*) _tmp26_, _tmp28_);
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp29_ = boxes_app_app;
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp30_ = _tmp29_->overlay_bin;
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp31_ = self->priv->display;
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					clutter_bin_layout_set_alignment (_tmp30_, (ClutterActor*) _tmp31_, CLUTTER_BIN_ALIGNMENT_FILL, CLUTTER_BIN_ALIGNMENT_FILL);
#line 454 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp32_ = self->priv->display;
#line 454 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					g_signal_connect_object ((ClutterActor*) _tmp32_, "transitions-completed", (GCallback) ______lambda83__clutter_actor_transitions_completed, self, 0);
#line 3904 "machine.c"
				} else {
					BoxesApp* _tmp33_;
					BoxesDisplayPage* _tmp34_;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp33_ = boxes_app_app;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					_tmp34_ = _tmp33_->display_page;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
					boxes_display_page_show (_tmp34_);
#line 3914 "machine.c"
				}
			}
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			break;
#line 3919 "machine.c"
		}
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 3923 "machine.c"
		{
			GtkEntry* _tmp35_;
			GtkEntry* _tmp36_;
			GtkLabel* _tmp37_;
#line 469 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp35_ = self->priv->password_entry;
#line 469 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			gtk_widget_set_can_focus ((GtkWidget*) _tmp35_, FALSE);
#line 470 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp36_ = self->priv->password_entry;
#line 470 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			gtk_widget_hide ((GtkWidget*) _tmp36_);
#line 471 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp37_ = self->priv->label;
#line 471 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			gtk_widget_show ((GtkWidget*) _tmp37_);
#line 472 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			break;
#line 3942 "machine.c"
		}
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 3946 "machine.c"
		{
			Block17Data* _data17_;
			BoxesApp* _tmp38_;
			BoxesDisplayPage* _tmp39_;
			GtkWidget* _tmp40_ = NULL;
			GtkWidget* widget;
			BoxesMachine* _tmp41_;
			BoxesDisplay* _tmp42_;
			BoxesDisplay* _tmp43_;
			GtkWidget* _tmp44_;
			GtkWidget* _tmp45_;
			GtkClutterActor* _tmp46_;
			GtkClutterActor* _tmp47_;
			GtkClutterActor* _tmp48_;
			BoxesApp* _tmp49_;
			ClutterBinLayout* _tmp50_;
			GtkClutterActor* _tmp51_;
			gint _tmp52_;
			gint _tmp53_;
			ClutterActorBox _tmp54_ = {0};
			ClutterActorBox box;
			GtkClutterActor* _tmp55_;
			ClutterActorBox _tmp56_;
			GtkClutterActor* _tmp57_;
			BoxesApp* _tmp58_;
			gboolean _tmp59_;
			gboolean _tmp60_;
			GtkClutterActor* _tmp65_;
			gulong _tmp66_ = 0UL;
			BoxesApp* _tmp67_;
			BoxesProperties* _tmp68_;
			GtkWidget* _tmp69_;
			gulong _tmp70_ = 0UL;
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data17_ = g_slice_new0 (Block17Data);
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data17_->_ref_count_ = 1;
#line 431 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data17_->self = g_object_ref (self);
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp38_ = boxes_app_app;
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp39_ = _tmp38_->display_page;
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp40_ = boxes_display_page_remove_display (_tmp39_);
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			widget = _tmp40_;
#line 476 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp41_ = self->priv->machine;
#line 476 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp42_ = boxes_machine_get_display (_tmp41_);
#line 476 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp43_ = _tmp42_;
#line 476 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp44_ = widget;
#line 476 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			boxes_display_set_enable_inputs (_tmp43_, _tmp44_, FALSE);
#line 477 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp45_ = widget;
#line 477 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp46_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents (_tmp45_);
#line 477 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			g_object_ref_sink (_tmp46_);
#line 477 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_g_object_unref0 (self->priv->display);
#line 477 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			self->priv->display = _tmp46_;
#line 478 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp47_ = self->priv->display;
#line 478 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			clutter_actor_set_name ((ClutterActor*) _tmp47_, "properties-thumbnail");
#line 479 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp48_ = self->priv->display;
#line 479 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			clutter_actor_set_easing_mode ((ClutterActor*) _tmp48_, CLUTTER_LINEAR);
#line 480 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp49_ = boxes_app_app;
#line 480 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp50_ = _tmp49_->overlay_bin;
#line 480 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp51_ = self->priv->display;
#line 480 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			clutter_bin_layout_add (_tmp50_, (ClutterActor*) _tmp51_, CLUTTER_BIN_ALIGNMENT_FILL, CLUTTER_BIN_ALIGNMENT_FILL);
#line 484 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp52_ = width;
#line 484 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp53_ = height;
#line 484 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp54_.x1 = (gfloat) 0;
#line 484 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp54_.y1 = (gfloat) 0;
#line 484 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp54_.x2 = (gfloat) _tmp52_;
#line 484 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp54_.y2 = (gfloat) _tmp53_;
#line 484 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			box = _tmp54_;
#line 485 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp55_ = self->priv->display;
#line 485 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp56_ = box;
#line 485 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			clutter_actor_allocate ((ClutterActor*) _tmp55_, &_tmp56_, 0);
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp57_ = self->priv->display;
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			clutter_actor_show ((ClutterActor*) _tmp57_);
#line 490 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp58_ = boxes_app_app;
#line 490 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp59_ = boxes_app_get_fullscreen (_tmp58_);
#line 490 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp60_ = _tmp59_;
#line 490 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			if (_tmp60_) {
#line 4062 "machine.c"
				BoxesApp* _tmp61_;
				BoxesTopbar* _tmp62_;
				ClutterActor* _tmp63_;
				ClutterActor* _tmp64_;
#line 491 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp61_ = boxes_app_app;
#line 491 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp62_ = _tmp61_->topbar;
#line 491 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp63_ = boxes_ui_get_actor ((BoxesUI*) _tmp62_);
#line 491 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				_tmp64_ = _tmp63_;
#line 491 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
				clutter_actor_hide (_tmp64_);
#line 4077 "machine.c"
			}
#line 493 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data17_->completed_zoom = FALSE;
#line 494 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data17_->completed_id = (gulong) 0;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp65_ = self->priv->display;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp66_ = g_signal_connect_data ((ClutterActor*) _tmp65_, "transitions-completed", (GCallback) ____lambda84__clutter_actor_transitions_completed, block17_data_ref (_data17_), (GClosureNotify) block17_data_unref, 0);
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data17_->completed_id = _tmp66_;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp67_ = boxes_app_app;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp68_ = _tmp67_->properties;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp69_ = _tmp68_->screenshot_placeholder;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_tmp70_ = g_signal_connect_data (_tmp69_, "size-allocate", (GCallback) ____lambda85__gtk_widget_size_allocate, block17_data_ref (_data17_), (GClosureNotify) block17_data_unref, 0);
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			self->priv->track_screenshot_id = _tmp70_;
#line 521 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_g_object_unref0 (widget);
#line 521 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			block17_data_unref (_data17_);
#line 521 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			_data17_ = NULL;
#line 521 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			break;
#line 4107 "machine.c"
		}
		default:
		{
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
			break;
#line 4113 "machine.c"
		}
	}
}


static ClutterActor* boxes_machine_actor_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesMachineActor* self;
	ClutterActor* _tmp0_;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = (BoxesMachineActor*) base;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->_actor;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	result = _tmp0_;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	return result;
#line 4131 "machine.c"
}


static void boxes_machine_actor_class_init (BoxesMachineActorClass * klass) {
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	boxes_machine_actor_parent_class = g_type_class_peek_parent (klass);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_type_class_add_private (klass, sizeof (BoxesMachineActorPrivate));
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_machine_actor_real_ui_state_changed;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_machine_actor_real_get_actor;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_machine_actor_get_property;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_machine_actor_finalize;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MACHINE_ACTOR_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4150 "machine.c"
}


static void boxes_machine_actor_instance_init (BoxesMachineActor * self) {
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv = BOXES_MACHINE_ACTOR_GET_PRIVATE (self);
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self->priv->track_screenshot_id = (gulong) 0;
#line 4159 "machine.c"
}


static void boxes_machine_actor_finalize (GObject* obj) {
	BoxesMachineActor * self;
	gulong _tmp0_;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActor);
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_tmp0_ = self->priv->track_screenshot_id;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 4172 "machine.c"
		BoxesApp* _tmp1_;
		BoxesProperties* _tmp2_;
		GtkWidget* _tmp3_;
		gulong _tmp4_;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp1_ = boxes_app_app;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp2_ = _tmp1_->properties;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp3_ = _tmp2_->screenshot_placeholder;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		_tmp4_ = self->priv->track_screenshot_id;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 4187 "machine.c"
	}
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->_actor);
#line 325 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->screenshot);
#line 326 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->gtk_vbox);
#line 327 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->display);
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->label);
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->vbox);
#line 330 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 331 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	_g_object_unref0 (self->priv->machine);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	G_OBJECT_CLASS (boxes_machine_actor_parent_class)->finalize (obj);
#line 4207 "machine.c"
}


GType boxes_machine_actor_get_type (void) {
	static volatile gsize boxes_machine_actor_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_machine_actor_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesMachineActorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_machine_actor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesMachineActor), 0, (GInstanceInitFunc) boxes_machine_actor_instance_init, NULL };
		GType boxes_machine_actor_type_id;
		boxes_machine_actor_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesMachineActor", &g_define_type_info, 0);
		g_once_init_leave (&boxes_machine_actor_type_id__volatile, boxes_machine_actor_type_id);
	}
	return boxes_machine_actor_type_id__volatile;
}


static void _vala_boxes_machine_actor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesMachineActor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActor);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
	switch (property_id) {
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		case BOXES_MACHINE_ACTOR_ACTOR:
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 4234 "machine.c"
		default:
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/machine.vala"
		break;
#line 4240 "machine.c"
	}
}



